@@ -102,12 +102,16 @@ def test_extract_from_bounds():
         upper=S_spot.upper,
     )
     X = repair_non_numeric(X, S_spot.var_type)
+    print(f"X: {X}")
     # (S-3): Eval initial design:
     y = fun(X)
     S_spot.min_y = min(y)
     S_spot.min_X = X[argmin(y)]
     # Kriging:
-    S = Kriging(name="kriging", seed=124, n_theta=2, noise=False, cod_type="norm")
+    S = Kriging(name="kriging", seed=124, noise=False, cod_type="norm")
+    S.fit(X, y)
+    print(f"S.k: {S.k}, S.n: {S.n}, S.nat_X.shape: {S.nat_X.shape}, S.nat_y.shape: {S.nat_y.shape}")
+    print(f"S.n_theta: {S.n_theta}")
     S.nat_X = copy.deepcopy(X)
     S.nat_y = copy.deepcopy(y)
     S.n = S.nat_X.shape[0]
@@ -124,6 +128,7 @@ def test_extract_from_bounds():
     S.ordered_mask = array(list(map(lambda x: x == "num" or x == "int" or x == "float", S.var_type)))
     S._initialize_variables(S.nat_X, S.nat_y)
     S.theta = zeros(S.n_theta)
+    print(f"theta: {S.theta}")
     # TODO: Currently not used:
     S.x0_theta = ones((S.n_theta,)) * S.n / (100 * S.k)
     S.p = ones(S.n_p) * 2.0
@@ -160,12 +165,13 @@ def test_extract_from_bounds():
         result = S.model_optimizer(func=S.fun_likelihood, bounds=S.de_bounds)
     # Finally, set new theta and p values and update the surrogate again
     # for new_theta_p_Lambda in de_results["x"]:
+    print(f"Result: {result}")
     new_theta_p_Lambda = result["x"]
     assert new_theta_p_Lambda.ndim == 1
     assert new_theta_p_Lambda.shape[0] == 2
 
     # 3rd example: 2nd example with noise (lambda)
-    S = Kriging(name="kriging", seed=124, n_theta=2, noise=True, cod_type="norm")
+    S = Kriging(name="kriging", seed=124, noise=True, cod_type="norm")
     S.nat_X = copy.deepcopy(X)
     S.nat_y = copy.deepcopy(y)
     S.n = S.nat_X.shape[0]
